import express from 'express';
import { Logger } from 'winston';
import { CompoundEntityRef } from '@backstage/catalog-model';
import { PipelineExecutionsResponse, PipelineStateResponse } from '@aws/aws-codepipeline-plugin-for-backstage-common';
import * as _backstage_backend_plugin_api from '@backstage/backend-plugin-api';
import { BackstageCredentials, AuthService, DiscoveryService, HttpAuthService } from '@backstage/backend-plugin-api';
import { CatalogApi } from '@backstage/catalog-client';
import { AwsResourceLocator } from '@aws/aws-core-plugin-for-backstage-node';
import { AwsCredentialsManager } from '@backstage/integration-aws-node';
import { Config } from '@backstage/config';

/**
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *   http://www.apache.org/licenses/LICENSE-2.0
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

interface AwsCodePipelineService {
    getPipelineExecutionsByEntity(options: {
        entityRef: CompoundEntityRef;
        credentials?: BackstageCredentials;
    }): Promise<PipelineExecutionsResponse>;
    getPipelineStateByEntity(options: {
        entityRef: CompoundEntityRef;
        credentials?: BackstageCredentials;
    }): Promise<PipelineStateResponse>;
}

/**
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *     http://www.apache.org/licenses/LICENSE-2.0
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

declare class DefaultAwsCodePipelineService implements AwsCodePipelineService {
    private readonly logger;
    private readonly auth;
    private readonly catalogApi;
    private readonly resourceLocator;
    private readonly credsManager;
    constructor(logger: Logger, auth: AuthService, catalogApi: CatalogApi, resourceLocator: AwsResourceLocator, credsManager: AwsCredentialsManager);
    static fromConfig(config: Config, options: {
        catalogApi: CatalogApi;
        discovery: DiscoveryService;
        auth?: AuthService;
        httpAuth?: HttpAuthService;
        logger: Logger;
        resourceLocator?: AwsResourceLocator;
    }): Promise<DefaultAwsCodePipelineService>;
    getPipelineExecutionsByEntity(options: {
        entityRef: CompoundEntityRef;
        credentials?: BackstageCredentials;
    }): Promise<PipelineExecutionsResponse>;
    getPipelineStateByEntity(options: {
        entityRef: CompoundEntityRef;
        credentials?: BackstageCredentials;
    }): Promise<PipelineStateResponse>;
    private getPipelineArnsForEntity;
    private getClient;
}

/**
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *   http://www.apache.org/licenses/LICENSE-2.0
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

interface RouterOptions {
    logger: Logger;
    awsCodePipelineApi: AwsCodePipelineService;
    discovery: DiscoveryService;
    auth?: AuthService;
    httpAuth?: HttpAuthService;
}
declare function createRouter(options: RouterOptions): Promise<express.Router>;

/**
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *   http://www.apache.org/licenses/LICENSE-2.0
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
declare const awsCodePiplinePlugin: _backstage_backend_plugin_api.BackendFeatureCompat;

export { DefaultAwsCodePipelineService, type RouterOptions, createRouter, awsCodePiplinePlugin as default };
